Writes example input files to a folder named "test_input", within the working directory.
Source:R/test_data.R
write_test_files.RdWrites example input files to a folder named "test_input", within the working directory.
R/test_data.R
write_test_files.RdWrites example input files to a folder named "test_input", within the working directory.